@@ -9,30 +9,30 @@ import pandas as pd
 from typing import Any, Dict, List
 import plotly.express as px
 import plotly.graph_objects as go
-from mitosheet.step_performers.graph.graph_utils import (
+from mitosheet.step_performers.graph_steps.graph_utils import (
     get_html_and_script_from_figure,
 )
 from mitosheet.sheet_functions.types.utils import is_number_dtype
 from mitosheet.types import ColumnHeader, ColumnID
-from mitosheet.mito_analytics import log
+from mitosheet.telemetry.telemetry_utils import log
 from mitosheet.steps_manager import StepsManager
 from mitosheet.step_performers.bulk_old_rename.deprecated_utils import deprecated
-from mitosheet.step_performers.graph.graph_utils import BAR, BOX, SCATTER
+from mitosheet.step_performers.graph_steps.graph_utils import BAR, BOX, SCATTER
 
 # Max number of unique non-number items to display in a graph.
 # NOTE: make sure to change both in unison so they make sense
 MAX_UNIQUE_NON_NUMBER_VALUES = 10_000
 
 
-def get_column_summary_graph(event: Dict[str, Any], steps_manager: StepsManager) -> str:
+def get_column_summary_graph(params: Dict[str, Any], steps_manager: StepsManager) -> str:
     """
     Creates a column summary graph and sends it back as a PNG
     string to the frontend for display.
     """
-    sheet_index = event['sheet_index']
-    column_id: ColumnID = event['column_id']
-    height = event['height']
-    width = event['width']
+    sheet_index = params['sheet_index']
+    column_id: ColumnID = params['column_id']
+    height = params['height']
+    width = params['width']
 
 
     # Create a copy of the dataframe, just for safety.
