@@ -9,7 +9,7 @@ This file contains helpful functions and classes for testing operations.
 
 import json
 from functools import wraps
-from typing import Any, Dict, List, Optional, Union
+from typing import Any, Dict, List, Optional, Tuple, Union
 from mitosheet.code_chunks.code_chunk_utils import get_code_chunks
 from mitosheet.step_performers.graph_steps.plotly_express_graphs import DO_NOT_CHANGE_PAPER_BGCOLOR_DEFAULT, DO_NOT_CHANGE_PLOT_BGCOLOR_DEFAULT, DO_NOT_CHANGE_TITLE_FONT_COLOR_DEFAULT
 from numpy import number
@@ -19,7 +19,7 @@ from mitosheet.mito_widget import MitoWidget, sheet
 from mitosheet.parser import parse_formula
 from mitosheet.transpiler.transpile import transpile
 from mitosheet.types import ColumnHeader, ColumnID, GraphID, MultiLevelColumnHeader
-from mitosheet.utils import dfs_to_array_for_json, get_new_id
+from mitosheet.utils import NpEncoder, dfs_to_array_for_json, get_new_id
 
 
 def decorate_all_functions(function_decorator):
@@ -59,7 +59,7 @@ def check_dataframes_equal(test_wrapper):
         df_name: df.copy(deep=True) for df, df_name in 
         zip(
             test_wrapper.mito_widget.steps_manager.original_args,
-            test_wrapper.mito_widget.steps_manager.steps[0].df_names
+            test_wrapper.mito_widget.steps_manager.steps_including_skipped[0].df_names
         )
     }
     final_dfs = {
@@ -107,7 +107,7 @@ def check_dataframes_equal(test_wrapper):
         test_wrapper.mito_widget.steps_manager.curr_step.column_filters,
         test_wrapper.mito_widget.steps_manager.curr_step.column_ids,
         test_wrapper.mito_widget.steps_manager.curr_step.column_format_types
-    ))
+    ), cls=NpEncoder)
 
 
 class MitoWidgetTestWrapper:
@@ -132,15 +132,15 @@ class MitoWidgetTestWrapper:
     def optimized_code_chunks(self):
         # NOTE: we don't add comments to this testing functionality, so that 
         # we don't have to change tests if we update comments
-        return get_code_chunks(self.mito_widget.steps_manager.steps, optimize=True)
+        return get_code_chunks(self.mito_widget.steps_manager.steps_including_skipped, optimize=True)
 
     @property
     def curr_step_idx(self):
         return self.mito_widget.steps_manager.curr_step_idx
     
     @property
-    def steps(self):
-        return self.mito_widget.steps_manager.steps
+    def steps_including_skipped(self):
+        return self.mito_widget.steps_manager.steps_including_skipped
 
     @property
     def curr_step(self):
@@ -216,21 +216,17 @@ class MitoWidgetTestWrapper:
             self, 
             how: str,
             sheet_index_one: int, 
-            merge_key_one: ColumnHeader, 
-            selected_columns_one: List[ColumnHeader],
             sheet_index_two: int, 
-            merge_key_two: ColumnHeader,
+            merge_key_columns: List[Tuple[ColumnHeader, ColumnHeader]], 
+            selected_columns_one: List[ColumnHeader],
             selected_columns_two: List[ColumnHeader]
         ) -> bool:
 
-        merge_key_column_id_one = self.mito_widget.steps_manager.curr_step.column_ids.get_column_id_by_header(
-            sheet_index_one,
-            merge_key_one
-        )
-        merge_key_column_id_two = self.mito_widget.steps_manager.curr_step.column_ids.get_column_id_by_header(
-            sheet_index_two,
-            merge_key_two
-        )
+        merge_key_column_ids = list(map(lambda x: [
+            self.mito_widget.steps_manager.curr_step.column_ids.get_column_id_by_header(sheet_index_one, x[0]),
+            self.mito_widget.steps_manager.curr_step.column_ids.get_column_id_by_header(sheet_index_two, x[1]),
+        ], merge_key_columns))
+
         selected_column_ids_one = [
             self.mito_widget.steps_manager.curr_step.column_ids.get_column_id_by_header(sheet_index_one, column_header)
             for column_header in selected_columns_one
@@ -250,10 +246,9 @@ class MitoWidgetTestWrapper:
                 'params': {
                     'how': how,
                     'sheet_index_one': sheet_index_one,
-                    'merge_key_column_id_one': merge_key_column_id_one,
-                    'selected_column_ids_one': selected_column_ids_one,
                     'sheet_index_two': sheet_index_two,
-                    'merge_key_column_id_two': merge_key_column_id_two,
+                    'merge_key_column_ids': merge_key_column_ids,
+                    'selected_column_ids_one': selected_column_ids_one,
                     'selected_column_ids_two': selected_column_ids_two
                 }
             }
@@ -310,6 +305,111 @@ class MitoWidgetTestWrapper:
             }
         )
 
+    
+    @check_transpiled_code_after_call
+    def delete_row(
+            self, 
+            sheet_index: int,
+            labels: List[Union[int, str]],
+        ) -> bool:        
+
+        return self.mito_widget.receive_message(
+            self.mito_widget,
+            {
+                'event': 'edit_event',
+                'id': get_new_id(),
+                'type': 'delete_row_edit',
+                'step_id': get_new_id(),
+                'params': {
+                    'sheet_index': sheet_index,
+                    'labels': labels,
+                }
+            }
+        )
+    
+
+    @check_transpiled_code_after_call
+    def promote_row_to_header(
+            self, 
+            sheet_index: int,
+            index: Any,
+        ) -> bool:
+        
+
+        return self.mito_widget.receive_message(
+            self.mito_widget,
+            {
+                'event': 'edit_event',
+                'id': get_new_id(),
+                'type': 'promote_row_to_header_edit',
+                'step_id': get_new_id(),
+                'params': {
+                    'sheet_index': sheet_index,
+                    'index': index,
+                    
+                }
+            }
+        )
+    
+
+    @check_transpiled_code_after_call
+    def transpose(
+            self, 
+            sheet_index: int,
+        ) -> bool:
+
+        
+
+        return self.mito_widget.receive_message(
+            self.mito_widget,
+            {
+                'event': 'edit_event',
+                'id': get_new_id(),
+                'type': 'transpose_edit',
+                'step_id': get_new_id(),
+                'params': {
+                    'sheet_index': sheet_index,
+                    
+                }
+            }
+        )
+    
+
+    @check_transpiled_code_after_call
+    def melt(
+            self, 
+            sheet_index: int,
+            id_var_column_headers: List[ColumnHeader],
+            value_var_column_headers: List[ColumnHeader],
+        ) -> bool:
+
+        id_var_column_ids = [
+            self.mito_widget.steps_manager.curr_step.column_ids.get_column_id_by_header(sheet_index, column_header)
+            for column_header in id_var_column_headers
+        ]
+        value_var_column_ids = [
+            self.mito_widget.steps_manager.curr_step.column_ids.get_column_id_by_header(sheet_index, column_header)
+            for column_header in value_var_column_headers
+        ]
+
+        return self.mito_widget.receive_message(
+            self.mito_widget,
+            {
+                'event': 'edit_event',
+                'id': get_new_id(),
+                'type': 'melt_edit',
+                'step_id': get_new_id(),
+                'params': {
+                    'sheet_index': sheet_index,
+                    'id_var_column_ids': id_var_column_ids,
+                    'value_var_column_ids': value_var_column_ids,
+                    
+                }
+            }
+        )
+    
+# AUTOGENERATED LINE: TEST (DO NOT DELETE)
+
     @check_transpiled_code_after_call
     def split_text_to_columns(
             self, 
@@ -625,7 +725,7 @@ class MitoWidgetTestWrapper:
         )
 
     @check_transpiled_code_after_call
-    def simple_import(self, file_names: List[str]) -> bool:
+    def simple_import(self, file_names: List[str], delimeters: Optional[List[str]]=None, encodings: Optional[List[str]]=None, error_bad_lines: Optional[List[bool]]=None) -> bool:
         return self.mito_widget.receive_message(
             self.mito_widget,
             {
@@ -634,7 +734,10 @@ class MitoWidgetTestWrapper:
                 'type': 'simple_import_edit',
                 'step_id': get_new_id(),
                 'params': {
-                    'file_names': file_names
+                    'file_names': file_names,
+                    'delimeters': delimeters,
+                    'encodings': encodings,
+                    'error_bad_lines': error_bad_lines,
                 }
             }
         )
@@ -837,10 +940,12 @@ class MitoWidgetTestWrapper:
         xaxis_title: Optional[str]=None,
         xaxis_visible: bool=True,
         xaxis_title_font_color: str=DO_NOT_CHANGE_TITLE_FONT_COLOR_DEFAULT,
+        xaxis_type: Optional[str]=None,
         xaxis_rangeslider_visible: bool=True,
         yaxis_title: Optional[str]=None,
         yaxis_visible: bool=True,
         yaxis_title_font_color: str=DO_NOT_CHANGE_TITLE_FONT_COLOR_DEFAULT,
+        yaxis_type: Optional[str]=None,
         showlegend: bool=True,
         step_id: str=None,
         paper_bgcolor: str=DO_NOT_CHANGE_PAPER_BGCOLOR_DEFAULT,
@@ -874,6 +979,7 @@ class MitoWidgetTestWrapper:
                             'title': xaxis_title,
                             'visible': xaxis_visible,
                             'title_font_color': xaxis_title_font_color,
+                            'type': xaxis_type,
                             'rangeslider': {
                                 'visible': xaxis_rangeslider_visible
                             }
@@ -882,6 +988,7 @@ class MitoWidgetTestWrapper:
                             'title': yaxis_title,
                             'visible': yaxis_visible,
                             'title_font_color': yaxis_title_font_color,
+                            'type': yaxis_type
                         },
                         'showlegend': showlegend,
                         'paper_bgcolor': paper_bgcolor,
